@@ -11,6 +11,10 @@ from kks.util.common import get_solution_directory, format_file, find_test_outpu
 
 
 @click.command(name='test', short_help='Test solutions')
+@click.option('-T', '-tg', '--target', default='default',
+              help='Target name to build')
+@click.option('-v', '--verbose', is_flag=True,
+              help='Verbose mode (show used gcc args)')
 @click.option('-t', '--test', 'tests', type=int, multiple=True,
               help='Test numbers to run (multiple are allowed)')
 @click.option('-r', '--range', 'test_range', type=int, nargs=2,
@@ -27,13 +31,13 @@ from kks.util.common import get_solution_directory, format_file, find_test_outpu
               help='Use asan (true by default)')
 @click.option('-g', '-vg', '--valgrind', is_flag=True,
               help='Use valgrind (disables asan)')
-@click.option('-v', '-vt', '--virtual', is_flag=True,
+@click.option('-V', '-vt', '--virtual', is_flag=True,
               help='Use virtual tests (generate tests in memory)')
 @click.option('--generator', type=click.Path(exists=True),
               help='generator for virtual tests (see "kks gen")')
 @click.option('--solution', type=click.Path(exists=True),
               help='solution for virtual tests')
-def test_(tests, test_range, files, sample,
+def test_(target, verbose, tests, test_range, files, sample,
           continue_on_error, ignore_exit_code, asan, valgrind,
           virtual, generator, solution):
     """
@@ -58,7 +62,7 @@ def test_(tests, test_range, files, sample,
         is_sample=sample,
     )
 
-    binary = compile_solution(directory, options)
+    binary = compile_solution(directory, target, verbose, options)
     if binary is None:
         return
 
